@@ -2,7 +2,7 @@ package DBIx::QuickDB::Driver::Percona;
 use strict;
 use warnings;
 
-our $VERSION = '0.000031';
+our $VERSION = '0.000032';
 
 use IPC::Cmd qw/can_run/;
 use Capture::Tiny qw/capture/;
@@ -62,9 +62,7 @@ my $NOT_PERCONA;
     }
 }
 
-#sub stop_sig { 'INT' }
-
-sub dbd_driver_order { grep { $_ } $ENV{QDB_PERCONA_DBD}, $ENV{QDB_MYSQLD_DBD}, 'DBD::mysql', 'DBD::MariaDB' }
+sub dbd_driver_order { grep { $_ } $ENV{QDB_PERCONA_DBD}, $ENV{QDB_MYSQLD_DBD}, 'DBD::mysql', 'DBD::Percona' }
 
 sub viable {
     my $this = shift;
@@ -74,7 +72,7 @@ sub viable {
 
     my @bad;
 
-    push @bad => "Could not load either 'DBD::mysql' or 'DBD::MariaDB', needed for everything"
+    push @bad => "Could not load either 'DBD::mysql' or 'DBD::Percona', needed for everything"
         unless $this->dbd_driver;
 
     if ($NOT_PERCONA) {
@@ -162,3 +160,74 @@ sub _default_config {
 1;
 
 __END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+DBIx::QuickDB::Driver::Percona - Percona MySQL driver for DBIx::QuickDB.
+
+=head1 DESCRIPTION
+
+Percona MySQL driver for L<DBIx::QuickDB>.
+
+=head1 SYNOPSIS
+
+See L<DBIx::QuickDB>.
+
+=head1 MYSQL SPECIFIC OPTIONS
+
+=over 4
+
+=item dbd_driver => $DRIVER
+
+Should be either L<DBD::mysql> or L<DBD::MariaDB>. If not specified then
+DBD::mysql is preferred with a fallback to DBD::MariaDB.
+
+=back
+
+=head1 ENVIRONMENT VARIABLES
+
+=head2 QDB_MYSQL_SSL_FIPS
+
+Set to 1 to enable, 0 to disable or enter any string accepted by the
+C<ssl_fips_mode> mysqld config option. If this environment variable is not
+defined then the C<ssl_fips_mode> option will not be included in the generated
+config file at all by default.
+
+This is mainly used to allow this dists test suite to pass on systems where
+FIPS is required and enforced.
+
+=head1 SOURCE
+
+The source code repository for DBIx-QuickDB can be found at
+F<https://github.com/exodist/DBIx-QuickDB/>.
+
+=head1 MAINTAINERS
+
+=over 4
+
+=item Chad Granum E<lt>exodist@cpan.orgE<gt>
+
+=back
+
+=head1 AUTHORS
+
+=over 4
+
+=item Chad Granum E<lt>exodist@cpan.orgE<gt>
+
+=back
+
+=head1 COPYRIGHT
+
+Copyright 2020 Chad Granum E<lt>exodist7@gmail.comE<gt>.
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+See F<http://dev.perl.org/licenses/>
+
+=cut
